==> guikachu-1.2.0.tar.gz: guikachu-1.2.0/src/widgets/target-combo.cc <==
//$Id: target-combo.cc,v 1.3 2002/01/03 17:19:35 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "widgets/target-combo.h"

#include "config.h"
#include <libgnome/libgnome.h>

#include <gtk--/menu.h>

#include "resource-manager.h"
#include "target.h"

using namespace Guikachu::GUI::PropertyEditors;

TargetCombo::TargetCombo ():
    PropertyEditor (this)
{
    Gtk::Menu *target_menu = new Gtk::Menu;
    std::map<std::string, std::string> targets = Target::stock_targets ();
    
    int current_index = 0;
    for (std::map<std::string, std::string>::iterator i = targets.begin ();
	 i != targets.end (); i++, current_index++)
    {
	target_menu->items ().push_back (Gtk::Menu_Helpers::MenuElem (
	    i->second, bind (slot (this, &TargetCombo::target_stock_cb), i->first)));
	
	stock_target_to_menuitem[i->first] = current_index;
    }
    
    target_menu->items ().push_back (Gtk::Menu_Helpers::MenuElem (
	_("Custom machine"), custom_selected.slot ()));
    num_targets = current_index;
    
    set_menu (*manage (target_menu));

    ResourceManager::get_target ()->changed.connect (SigC::slot (this, &TargetCombo::update));
    update ();
}

void TargetCombo::update ()
{
    std::string target_id = ResourceManager::get_target ()->get_stock_id ();
    if (target_id != "")
	set_history (stock_target_to_menuitem[target_id]);
    else
	set_history (num_targets);
}

void TargetCombo::target_stock_cb (std::string stock_id)
{
    ResourceManager::get_target ()->load_stock (stock_id);

    stock_selected.emit ();
}

==> guikachu-1.3.0.tar.gz: guikachu-1.3.0/src/widgets/target-combo.cc <==
//$Id: target-combo.cc,v 1.4 2002/06/02 13:53:43 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "widgets/target-combo.h"

#include "config.h"
#include <libgnome/libgnome.h>

#include <gtk--/menu.h>

#include "resource-manager.h"
#include "target.h"

using namespace Guikachu::GUI::PropertyEditors;

TargetCombo::TargetCombo (ResourceManager *manager):
    PropertyEditor (this),
    target (manager->get_target ())
{
    Gtk::Menu *target_menu = new Gtk::Menu;
    std::map<std::string, std::string> targets = Target::stock_targets ();
    
    int current_index = 0;
    for (std::map<std::string, std::string>::iterator i = targets.begin ();
	 i != targets.end (); i++, current_index++)
    {
	target_menu->items ().push_back (Gtk::Menu_Helpers::MenuElem (
	    i->second, bind (slot (this, &TargetCombo::target_stock_cb), i->first)));
	
	stock_target_to_menuitem[i->first] = current_index;
    }
    
    target_menu->items ().push_back (Gtk::Menu_Helpers::MenuElem (
	_("Custom machine"), custom_selected.slot ()));
    num_targets = current_index;
    
    set_menu (*manage (target_menu));

    target->changed.connect (SigC::slot (this, &TargetCombo::update));
    update ();
}

void TargetCombo::update ()
{
    std::string target_id = target->get_stock_id ();
    if (target_id != "")
	set_history (stock_target_to_menuitem[target_id]);
    else
	set_history (num_targets);
}

void TargetCombo::target_stock_cb (std::string stock_id)
{
    target->load_stock (stock_id);

    stock_selected.emit ();
}
